// Copyright (C) 2018 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR GPL-3.0-only

//  W A R N I N G
//  -------------
//
// This file is not part of the Qt Chart API.  It exists purely as an
// implementation detail.  This header file may change from version to
// version without notice, or even be removed.
//
// We mean it.

#ifndef DECLARATIVECHARTGLOBAL_H
#define DECLARATIVECHARTGLOBAL_H

#include <QtCore/QtGlobal>
#include <qtcharts-config.h>
#include <QtChartsQml/private/qtchartsqmlexports_p.h>

void Q_CHARTSQML_PRIVATE_EXPORT qml_register_types_QtCharts();

#endif // DECLARATIVECHARTGLOBAL_H
